__author__ = 'sannies'

import os
os.environ['DJANGO_SETTINGS_MODULE'] = 'local_settings'

import settings

from suds.client import Client
from suds import WebFault
from urllib2 import URLError
import suds.xsd.doctor as dr

wsdlurl = settings.SERVER_URI

# The following dictionary has the targetNamespace as the key and a list
# of namespaces that need to be imported as the value for that key
patches = { "urn:SecurityServer": ["http://authentication.integration.crowd.atlassian.com",
    "http://soap.integration.crowd.atlassian.com","http://exception.integration.crowd.atlassian.com",
    "http://rmi.java"] ,
    "http://soap.integration.crowd.atlassian.com": ["urn:SecurityServer"] }

# Create an ImportDoctor to use
doctor = dr.ImportDoctor()

# Patch all the imports into the proper targetNamespaces
for targetNamespace in patches:
    for ns_import in patches[targetNamespace]:
        imp = dr.Import(ns_import)
        imp.filter.add(targetNamespace)
        doctor.add(imp)

# Create the SOAP client, doctoring it to fix imports
try:
    client = Client(wsdlurl,doctor=doctor,timeout=settings.URI_TIMEOUT)
    print (client)
except URLError as err:
    print 'Caught exception trying to load wsdl: %s' % err.reason
    exit()

auth_context = client.factory.create('ns1:ApplicationAuthenticationContext')

auth_context.name = settings.APPLICATION_USER
auth_context.credential.credential = settings.APPLICATION_PASSWORD

try:
    token = client.service.authenticateApplication(auth_context)
except WebFault as wf:
    print 'Exception in authenticateApplication: %s' % wf
    exit()

principalToken = client.service.authenticatePrincipalSimple(token,
                                        settings.PRINCIPAL_USER,
                                        settings.PRINCIPAL_PASSWORD)
print client.service.findGroupMemberships(token, settings.PRINCIPAL_PASSWORD)
principal = client.service.findPrincipalByToken(token, principalToken)

a = client.service.getCookieInfo(token)
print a

# Create validation factor
myValidationFactor = client.factory.create("ns0:ValidationFactor")
myValidationFactor.name ="remote_address"
myValidationFactor.value = '0:0:0:0:0:0:0:1'

print client.service.isValidPrincipalToken(token, principalToken, [myValidationFactor])

#for soapAttribute in principal.attributes[0]:
#    print soapAttribute
#pass
